/* Copyright (c) 2009-2020. The SimGrid Team. All rights reserved.          */

/* This program is free software; you can redistribute it and/or modify it
 * under the terms of the license (GNU LGPL) which comes with this package. */
#ifndef SIMGRID_PLUGINS_LOAD_BALANCER_H_
#define SIMGRID_PLUGINS_LOAD_BALANCER_H_

#include <simgrid/forward.h>
#include <xbt/base.h>

SG_BEGIN_DECL

XBT_PUBLIC void sg_load_balancer_plugin_init();

SG_END_DECL

#endif
